/*!
 * dd-vue-matomo v0.1.0
 * (c) 2019 Dennis Ruhe
 * Released under the MIT License.
 */

(function (global, factory) {
	typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports) :
	typeof define === 'function' && define.amd ? define(['exports'], factory) :
	(factory((global.DdVueMatomo = global.DdVueMatomo || {})));
}(this, (function (exports) { 'use strict';

var bootstrap = function (options) {
  var host = options.host;
  var filename = host + '/piwik.js';

  var scriptPromise = new Promise(function (resolve, reject) {
    var script = document.createElement('script');
    script.async = true;
    script.defer = true;
    script.src = filename;

    var head = document.head || document.getElementsByTagName('head')[0];
    head.appendChild(script);

    script.onload = resolve;
    script.onerror = reject;
  });

  scriptPromise.catch(function (error) {
    console.error('Error loading script', error);
  });

  return scriptPromise
};

var defaultOptions = {
  requireConsent: false,
  trackInitialView: true
};

function install (Vue, setupOptions) {
  if ( setupOptions === void 0 ) setupOptions = {};

  var options = Object.assign({}, defaultOptions, setupOptions);

  bootstrap(options)
    .then(function () {
      var host = options.host;
      var siteId = options.siteId;
      var matomo = window.Piwik.getTracker(host + '/piwik.php', siteId);

      // Assign matomo to Vue
      Vue.prototype.$piwik = matomo;
      Vue.prototype.$matomo = matomo;

      if (options.requireConsent) {
        matomo.requireConsent();
      }

      // Register first page view
      if (options.trackInitialView) {
        matomo.trackPageView();
      }

      // Track page navigations if router is specified
      if (options.router) {
        var baseRoute = options.router.base;
        options.router.afterEach(function (to, from) {
          // Unfortunately the window location is not yet updated here
          // We need to make our own ulr using the data provided by the router
          var loc = window.location;

          // Protocol may or may not contain a colon
          var protocol = loc.protocol;
          if (protocol.slice(-1) !== ':') {
            protocol += ':';
          }

          var url = protocol + '//' + loc.host + to.path;
          if (baseRoute) {
            url = protocol + '//' + loc.host + baseRoute + to.path;
          } else {
            url = protocol + '//' + loc.host + to.path;
          }
          matomo.setCustomUrl(url);
          matomo.trackPageView(to.name);
        });
      }
    });
}

exports['default'] = install;

Object.defineProperty(exports, '__esModule', { value: true });

})));
